# oc_sprint_datetime

> My template for small libraries and command-line tools.

[![PyPI Version][pypi-image]][pypi-url]
[![Build Status][build-image]][build-url]
[![Code Coverage][coverage-image]][coverage-url]
[![Code Quality][quality-image]][quality-url]

## Installation

```sh
pip install oc_sprint_datetime
```

<!-- Badges -->

[pypi-image]: https://img.shields.io/pypi/v/oc_sprint_datetime
[pypi-url]: https://pypi.org/project/oc_sprint_datetime/
[build-image]: https://github.com/0x29a/oc_sprint_datetime/actions/workflows/build.yml/badge.svg
[build-url]: https://github.com/0x29a/oc_sprint_datetime/actions/workflows/build.yml
[coverage-image]: https://codecov.io/gh/0x29a/oc_sprint_datetime/branch/master/graph/badge.svg
[coverage-url]: https://codecov.io/gh/0x29a/oc_sprint_datetime
[quality-image]: https://api.codeclimate.com/v1/badges/6e64bdcfef686ced4b10/maintainability
[quality-url]: https://codeclimate.com/github/0x29a/oc_sprint_datetime
